@@ -130,7 +130,6 @@ class Specifications(paramtools.Parameters):
             )
 
         # Extend parameters that may vary over the time path
-        # those that vary over m: 'Z', 'cit_rate',
         tp_param_list = [
             "alpha_G",
             "alpha_T",
@@ -166,7 +165,13 @@ class Specifications(paramtools.Parameters):
             )
             setattr(self, item, this_attr)
         # Deal with parameters that vary across industry and over time
-        tp_param_list2 = ["Z", "delta_tau_annual", "cit_rate", "tau_c"]
+        tp_param_list2 = [
+            "Z",
+            "delta_tau_annual",
+            "cit_rate",
+            "tau_c",
+            "inv_tax_credit",
+        ]
         for item in tp_param_list2:
             this_attr = getattr(self, item)
             if this_attr.ndim == 1:
